[−][src]Struct alsa::seq::Input
Struct for receiving input events from a sequencer. The methods offered by this
object may modify the internal input buffer of the sequencer, which must not happen
while an Event is alive that has been obtained from a call to event_input (which
takes Input by mutable reference for this reason). This is because the event might
directly reference the sequencer's input buffer for variable-length messages (e.g. Sysex).
Note: Only one Input object is allowed in scope at a time.
Methods
impl<'a> Input<'a>[src]
pub fn event_input<'b>(&'b mut self) -> Result<Event<'b>>[src]
pub fn event_input_pending(&self, fetch_sequencer: bool) -> Result<u32>[src]
pub fn set_input_buffer_size(&self, size: u32) -> Result<()>[src]